﻿using System;
using System.Collections.Generic;
using System.Configuration;
using System.Linq;
using System.Web;
using System.Web.Configuration;
using System.Xml;

namespace StudyCommerceTimerTask.TimerTask {
	/// <summary>
	/// 描述Nopconfig
	/// Yuhao 2014.5.6 Add
	/// </summary>
	public partial class NopConfig:IConfigurationSectionHandler {

		#region Fields
		/// <summary>
		/// 链接字符串
		/// </summary>
		private static string _connectionString = "";
		/// <summary>
		/// 判断是否第一次初始化
		/// </summary>
		private static bool _initialize = false;
		/// <summary>
		/// Cookie失效时间
		/// </summary>
		private static int _cookieExpires = 128;
		/// <summary>
		/// 是否开启缓存
		/// </summary>
		private static bool _cacheEnable = false;
		/// <summary>
		/// 计划任务
		/// </summary>
		private static XmlNode _scheduleTasks;

		#endregion

		#region Methods
		public object Create(object parent, object configContext, XmlNode section)
		{
			XmlNode sqlServerNode = section.SelectSingleNode("SqlServer");
			if (sqlServerNode != null)
			{
				XmlAttribute attribute = sqlServerNode.Attributes["ConnectionStringName"];
				if ((attribute != null) && (WebConfigurationManager.ConnectionStrings[attribute.Value] != null))
				{
					_connectionString = WebConfigurationManager.ConnectionStrings[attribute.Value].ConnectionString;
				}
			}
			XmlNode cacheNode = section.SelectSingleNode("Cache");
			if (cacheNode != null)
			{
				XmlAttribute attribute = cacheNode.Attributes["Enabled"];
				if (attribute != null && attribute.Value != null)
				{
					string str = attribute.Value.ToLowerInvariant();
					_cacheEnable = (str == "TRUE" || str == "YES" || str == "1");
				}
			}
			_scheduleTasks = section.SelectSingleNode("ScheduleTasks");
			return null;
		}

		public static void Init()
		{
			if (!_initialize)
			{
				//初始化获取Section 节点
				ConfigurationManager.GetSection("NopConfig");
				_initialize = true;
			}
		}
		#endregion

		#region Properties

		/// <summary>
		/// 获取链接字符串
		/// </summary>
		public static string ConnectionString
		{
			get
			{
				return _connectionString;
			}
			set
			{
				_connectionString = value;
			}
		}

		/// <summary>
		/// cookies过期时间
		/// </summary>
		public static int CookieExpires
		{
			get
			{
				return _cookieExpires;
			}
			set
			{
				_cookieExpires = value;
			}
		}

		/// <summary>
		/// 是否开启缓存
		/// </summary>
		public static bool CacheEnabled
		{
			get
			{
				return _cacheEnable;
			}
			set
			{
				_cacheEnable = value;
			}
		}


		/// <summary>
		/// 计划任务数组的节点
		/// </summary>
		public static XmlNode ScheduleTasks
		{
			get
			{
				return _scheduleTasks;
			}
			set
			{
				_scheduleTasks = value;
			}
		}
		#endregion

	}
}