﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Web;
using System.Xml;

namespace StudyCommerceTimerTask.TimerTask {

	/// <summary>
	/// 任务管理器-单利实例
	/// Yuhao 2014.5.6 Add
	/// </summary>
	public partial class TaskManager {
		#region Fields
		private static readonly TaskManager _taskManager = new TaskManager();
		private List<TaskThread> _taskThreads = new List<TaskThread>();
		#endregion

		#region .ctor
		/// <summary>
		/// 无参私有构造函数
		/// </summary>
		private TaskManager() {

		}
		#endregion

		#region Methods

		/// <summary>
		/// 线程出错异常处理
		/// </summary>
		/// <param name="task"></param>
		/// <param name="exception"></param>
		internal void ProcessException(Task task, Exception exception) {
			try {
				//Process exception code here
			} catch {


			}
		}

		/// <summary>
		/// 初始化任务管理器的属性值在配置文件
		/// 这是第一种方法直接传递路径和节点名称
		/// </summary>
		/// <param name="configFile"></param>
		/// <param name="nodePath"></param>
		public void Initialize(string configFile, string nodePath) {
			var document = new XmlDocument();
			document.Load(configFile);
			Initialize(document.SelectSingleNode(nodePath));

		}

		/// <summary>
		/// 初始化配置文件节点
		/// 这是第二种利用GetSection 初始化接口IConfigurationSectionHandler
		/// </summary>
		/// <param name="node"></param>
		public void Initialize(XmlNode node) {
			this._taskThreads.Clear();
			foreach (XmlNode node1 in node.ChildNodes) {
				if (node1.Name.ToLower() == "thread") {
					var taskThread = new TaskThread(node1);
					this._taskThreads.Add(taskThread);
					foreach (XmlNode node2 in node1.ChildNodes) {
						if (node2.Name.ToLower() == "task") {
							var attribute = node2.Attributes["type"];
							var taskType = Type.GetType(attribute.Value);
							if (taskType != null) {
								var task = new Task(taskType, node2);
								taskThread.AddTask(task);
							}
						}

					}
				}
			}
		}

		/// <summary>
		/// 开始任务管理的所有定时任务
		/// </summary>
		public void Start() {
			foreach (var taskThread in _taskThreads) {
				//开始执行任务的计时器
				taskThread.InitTimer();
			}
		}

		/// <summary>
		/// 清理任务管理器所有的定时任务
		/// </summary>
		public void Stop() {
			foreach (var taskThread in _taskThreads) {
				//停止计时器
				taskThread.Dispose();
			}
		}

		#endregion

		#region Properties

		/// <summary>
		/// 获取任务管理实例 形成单列实例
		/// </summary>
		public static TaskManager Instance {
			get {
				return _taskManager;
			}
		}

		/// <summary>
		/// 获取当前任务管理所有的线程任务
		/// </summary>
		public IList<TaskThread> TaskThreads {
			get {
				return new ReadOnlyCollection<TaskThread>(_taskThreads);
			}
		}
		#endregion
	}
}